@@ -1,6 +1,6 @@
 /*
- * ZMap Copyright 2013 Regents of the University of Michigan 
- * 
+ * ZMap Copyright 2013 Regents of the University of Michigan
+ *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not
  * use this file except in compliance with the License. You may obtain a copy
  * of the License at http://www.apache.org/licenses/LICENSE-2.0
@@ -61,17 +61,6 @@ static uint16_t num_src_ports;
 // global sender initialize (not thread specific)
 iterator_t* send_init(void)
 {
-	// compute number of targets
-	uint64_t allowed = blacklist_count_allowed();
-	assert(allowed <= (1LL << 32));
-	if (allowed == (1LL << 32)) {
-		zsend.targets = 0xFFFFFFFF;
-	} else {
-		zsend.targets = allowed;
-	}
-	if (zsend.targets > zconf.max_targets) {
-		zsend.targets = zconf.max_targets;
-	}
 
 	// generate a new primitive root and starting position
 	iterator_t *it;
@@ -119,8 +108,8 @@ iterator_t* send_init(void)
 	// concert specified bandwidth to packet rate
 	if (zconf.bandwidth > 0) {
 		int pkt_len = zconf.probe_module->packet_length;
-		pkt_len *= 8;	
-		pkt_len += 8*24;	// 7 byte MAC preamble, 1 byte Start frame, 
+		pkt_len *= 8;
+		pkt_len += 8*24;	// 7 byte MAC preamble, 1 byte Start frame,
 		                        // 4 byte CRC, 12 byte inter-frame gap
 		if (pkt_len < 84*8) {
 			pkt_len = 84*8;
@@ -146,6 +135,9 @@ iterator_t* send_init(void)
 			  "interface: %s", zconf.iface);
 		return NULL;
 	}
+     log_debug("send", "source MAC address %02x:%02x:%02x:%02x:%02x:%02x",
+           zconf.hw_mac[0], zconf.hw_mac[1], zconf.hw_mac[2],
+           zconf.hw_mac[3], zconf.hw_mac[4], zconf.hw_mac[5]);
 
 	if (zconf.dryrun) {
 		log_info("send", "dryrun mode -- won't actually send packets");
@@ -154,7 +146,7 @@ iterator_t* send_init(void)
 	// initialize random validation key
 	validate_init();
 
-	zsend.start = now();	
+	zsend.start = now();
 	return it;
 }
 
@@ -163,7 +155,7 @@ static inline ipaddr_n_t get_src_ip(ipaddr_n_t dst, int local_offset)
 	if (srcip_first == srcip_last) {
 		return srcip_first;
 	}
-	return htonl(((ntohl(dst) + srcip_offset + local_offset) 
+	return htonl(((ntohl(dst) + srcip_offset + local_offset)
 			% num_src_addrs)) + srcip_first;
 }
 
@@ -214,7 +206,7 @@ int send_run(int sock, shard_t *s)
 					      zconf.target_port);
 	}
 	pthread_mutex_unlock(&send_mutex);
-	
+
 	// adaptive timing to hit target rate
 	uint32_t count = 0;
 	uint32_t last_count = count;
@@ -241,7 +233,7 @@ int send_run(int sock, shard_t *s)
 				;
 			if (!interval || (count % interval == 0)) {
 				double t = now();
-				delay *= (double)(count - last_count) 
+				delay *= (double)(count - last_count)
 					/ (t - last_time) / (zconf.rate / zconf.senders);
 				if (delay < 1)
 					delay = 1;
