@@ -1,6 +1,6 @@
 /*
- * ZMap Copyright 2013 Regents of the University of Michigan 
- * 
+ * ZMap Copyright 2013 Regents of the University of Michigan
+ *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not
  * use this file except in compliance with the License. You may obtain a copy
  * of the License at http://www.apache.org/licenses/LICENSE-2.0
@@ -54,28 +54,33 @@
 pthread_mutex_t cpu_affinity_mutex = PTHREAD_MUTEX_INITIALIZER;
 pthread_mutex_t recv_ready_mutex = PTHREAD_MUTEX_INITIALIZER;
 
+static int max(int a, int b) {
+	if (a >= b) {
+		return a;
+	}
+	return b;
+}
+
 // splits comma delimited string into char*[]. Does not handle
 // escaping or complicated setups: designed to process a set
-// of fields that the user wants output 
+// of fields that the user wants output
 static void split_string(char* in, int *len, char***results)
 {
-	char** fields = calloc(MAX_FIELDS, sizeof(char*));
-	memset(fields, 0, MAX_FIELDS*sizeof(fields));
+	char** fields = xcalloc(MAX_FIELDS, sizeof(char*));
 	int retvlen = 0;
-	char *currloc = in; 
+	char *currloc = in;
 	// parse csv into a set of strings
 	while (1) {
-		size_t len = strcspn(currloc, ", ");    
+		size_t len = strcspn(currloc, ", ");
 		if (len == 0) {
 			currloc++;
 		} else {
-			char *new = malloc(len+1);
-			assert(new);
+			char *new = xmalloc(len+1);
 			strncpy(new, currloc, len);
-			new[len] = '\0';	     
+			new[len] = '\0';
 			fields[retvlen++] = new;
 			assert(fields[retvlen-1]);
-		}   
+		}
 		if (len == strlen(currloc)) {
 			break;
 		}
@@ -90,9 +95,9 @@ static void split_string(char* in, int *len, char***results)
 void fprintw(FILE *f, char *s, size_t w)
 {
 	if (strlen(s) <= w) {
-		fprintf(f, "%s", s); 
+		fprintf(f, "%s", s);
 		return;
-	}   
+	}
 	// process each line individually in order to
 	// respect existing line breaks in string.
 	char *news = strdup(s);
@@ -102,7 +107,7 @@ void fprintw(FILE *f, char *s, size_t w)
 			printf("%s\n", pch);
 			pch = strtok(NULL, "\n");
 			continue;
-		}   
+		}
 		char *t = pch;
 		while (strlen(t)) {
 			size_t numchars = 0; //number of chars to print
@@ -110,7 +115,7 @@ void fprintw(FILE *f, char *s, size_t w)
 			while (1) {
 				size_t new = strcspn(tmp, " ") + 1;
 				if (new == strlen(tmp) || new > w) {
-					// there are no spaces in the string, so, just 
+					// there are no spaces in the string, so, just
 					// print the entire thing on one line;
 					numchars += new;
 					break;
@@ -121,16 +126,16 @@ void fprintw(FILE *f, char *s, size_t w)
 				} else {
 					tmp += (size_t) new;
 					numchars += new;
-				}   
-			}   
-			fprintf(f, "%.*s\n", (int) numchars, t); 
+				}
+			}
+			fprintf(f, "%.*s\n", (int) numchars, t);
 			t += (size_t) numchars;
 			if (t > pch + (size_t)strlen(pch)) {
 				break;
-			}   
-		}   
+			}
+		}
 		pch = strtok(NULL, "\n");
-	}   
+	}
 	free(news);
 }
 
@@ -171,7 +176,7 @@ static void set_cpu(void)
 	pthread_mutex_lock(&cpu_affinity_mutex);
 	static int core=0;
 	int num_cores = sysconf(_SC_NPROCESSORS_ONLN);
-	cpu_set_t cpuset;	
+	cpu_set_t cpuset;
 	CPU_ZERO(&cpuset);
 	CPU_SET(core, &cpuset);
 
@@ -219,7 +224,7 @@ static void drop_privs()
 			return; // success
 		}
 	}
-	log_fatal("zmap", "Couldn't change UID to 'nobody'");		
+	log_fatal("zmap", "Couldn't change UID to 'nobody'");
 }
 
 typedef struct mon_start_arg {
@@ -319,7 +324,7 @@ static void json_metadata(FILE *file)
 			log_error("json-metadata", "unable to retrieve complete hostname");
 		}
 	}
-	
+
 	json_object_object_add(obj, "target-port",
 			json_object_new_int(zconf.target_port));
 	json_object_object_add(obj, "source-port-first",
@@ -338,7 +343,7 @@ static void json_metadata(FILE *file)
 	json_object_object_add(obj, "senders", json_object_new_int(zconf.senders));
 	json_object_object_add(obj, "use-seed", json_object_new_int(zconf.use_seed));
 	json_object_object_add(obj, "seed", json_object_new_int(zconf.seed));
-	json_object_object_add(obj, "generator", json_object_new_int(zconf.generator));
+	json_object_object_add(obj, "generator", json_object_new_int64(zconf.generator));
 	json_object_object_add(obj, "hitrate", json_object_new_double(hitrate));
 	json_object_object_add(obj, "shard-num", json_object_new_int(zconf.shard_num));
 	json_object_object_add(obj, "total-shards", json_object_new_int(zconf.total_shards));
@@ -368,7 +373,7 @@ static void json_metadata(FILE *file)
 			json_object_new_string(((probe_module_t *)zconf.probe_module)->name));
 	json_object_object_add(obj, "output-module",
 			json_object_new_string(((output_module_t *)zconf.output_module)->name));
-	
+
 	json_object_object_add(obj, "send-start-time",
 			json_object_new_string(send_start_time));
 	json_object_object_add(obj, "send-end-time",
@@ -390,7 +395,7 @@ static void json_metadata(FILE *file)
 
 	if (zconf.destination_cidrs_len) {
 		json_object *cli_dest_cidrs = json_object_new_array();
-		for (int i=0; i < zconf.destination_cidrs_len; i++) { 
+		for (int i=0; i < zconf.destination_cidrs_len; i++) {
 			json_object_array_add(cli_dest_cidrs, json_object_new_string(zconf.destination_cidrs[i]));
 		}
 		json_object_object_add(obj, "cli-cidr-destinations",
@@ -450,7 +455,7 @@ static void json_metadata(FILE *file)
 	}
 	if (zconf.blacklist_filename) {
 		json_object_object_add(obj,
-			"blacklist-filename", 
+			"blacklist-filename",
 			json_object_new_string(zconf.blacklist_filename));
 	}
 	if (zconf.whitelist_filename) {
@@ -506,7 +511,7 @@ static void start_zmap(void)
 	}
 	if (zconf.source_ip_first == NULL) {
 		struct in_addr default_ip;
-		zconf.source_ip_first = malloc(INET_ADDRSTRLEN);
+		zconf.source_ip_first = xmalloc(INET_ADDRSTRLEN);
 		zconf.source_ip_last = zconf.source_ip_first;
 		if (get_iface_ip(zconf.iface, &default_ip) < 0) {
 			log_fatal("zmap", "could not detect default IP address for for %s."
@@ -523,9 +528,9 @@ static void start_zmap(void)
 					" Try setting default gateway mac address (-G).",
 					zconf.iface);
 		}
-		log_debug("zmap", "found gateway IP %s on %s", inet_ntoa(gw_ip), zconf.iface); 
+		log_debug("zmap", "found gateway IP %s on %s", inet_ntoa(gw_ip), zconf.iface);
 		zconf.gw_ip = gw_ip.s_addr;
-		
+
 		if (get_hw_addr(&gw_ip, zconf.iface, zconf.gw_mac)) {
 			log_fatal("zmap", "could not detect GW MAC address for %s on %s."
 					" Try setting default gateway mac address (-G), or run"
@@ -551,12 +556,7 @@ static void start_zmap(void)
 		zconf.output_module->init(&zconf, zconf.output_fields,
 				zconf.output_fields_len);
 	}
-	// blacklist
-	if (blacklist_init(zconf.whitelist_filename, zconf.blacklist_filename,
-			   zconf.destination_cidrs, zconf.destination_cidrs_len,
-			   NULL, 0)) {
-		log_fatal("zmap", "unable to initialize blacklist / whitelist");
-	}
+
 	iterator_t *it = send_init();
 	if (!it) {
 		log_fatal("zmap", "unable to initialize sending component");
@@ -579,8 +579,7 @@ static void start_zmap(void)
 		}
 		pthread_mutex_unlock(&recv_ready_mutex);
 	}
-	tsend = malloc(zconf.senders * sizeof(pthread_t));
-	assert(tsend);
+	tsend = xmalloc(zconf.senders * sizeof(pthread_t));
 	for (uint8_t i = 0; i < zconf.senders; i++) {
 		int sock;
 		if (zconf.dryrun) {
@@ -659,15 +658,6 @@ static void enforce_range(const char *name, int v, int min, int max)
 	}
 }
 
-static int file_exists(char *name)
-{
-	FILE *file = fopen(name, "r");
-	if (!file)
-		return 0;
-	fclose(file);
-	return 1;
-}
-
 #define MAC_LEN ETHER_ADDR_LEN
 int parse_mac(macaddr_t *out, char *in)
 {
@@ -707,7 +697,7 @@ int main(int argc, char *argv[])
 	if (cmdline_parser_ext(argc, argv, &args, params) != 0) {
 		exit(EXIT_SUCCESS);
 	}
-	if (args.config_given || file_exists(args.config_arg)) {
+	if (args.config_given) {
 		params->initialize = 0;
 		params->override = 0;
 		if (cmdline_parser_config_file(args.config_arg, &args, params) 
@@ -738,7 +728,7 @@ int main(int argc, char *argv[])
 		struct tm *local = localtime(&now);
 		char path[100];
 		strftime(path, 100, "zmap-%Y-%m-%dT%H%M%S%z.log", local);
-		char *fullpath = malloc(strlen(zconf.log_directory) + strlen(path) + 2);
+		char *fullpath = xmalloc(strlen(zconf.log_directory) + strlen(path) + 2);
 		sprintf(fullpath, "%s/%s", zconf.log_directory, path);
 		log_location = fopen(fullpath, "w");
 		free(fullpath);
@@ -769,7 +759,7 @@ int main(int argc, char *argv[])
 	// specified and then map these into new-style output modules and warn
 	// users that they need to be switching to the new module interface.
 
-	// zmap's default behavior is to provide a simple file of the unique IP 
+	// zmap's default behavior is to provide a simple file of the unique IP
 	// addresses that responded successfully.
 	if (!strcmp(args.output_module_arg, "default")) {
 		log_debug("zmap", "no output module provided. will use csv.");
@@ -781,7 +771,7 @@ int main(int argc, char *argv[])
 		log_warn("zmap", "the simple_file output interface has been deprecated and "
 				 "will be removed in the future. Users should use the csv "
 				 "output module. Newer scan options such as output-fields "
-				 "are not supported with this output module."); 
+				 "are not supported with this output module.");
 		zconf.output_module = get_output_module_by_name("csv");
 		zconf.raw_output_fields = (char*) "saddr";
 		zconf.filter_duplicates = 1;
@@ -790,7 +780,7 @@ int main(int argc, char *argv[])
 		log_warn("zmap", "the extended_file output interface has been deprecated and "
 				 "will be removed in the future. Users should use the csv "
 				 "output module. Newer scan options such as output-fields "
-				 "are not supported with this output module."); 
+				 "are not supported with this output module.");
 		zconf.output_module = get_output_module_by_name("csv");
 		zconf.raw_output_fields = (char*) "classification, saddr, "
 						  "daddr, sport, dport, "
@@ -901,7 +891,7 @@ int main(int argc, char *argv[])
 	}
 	// find the fields we need for the framework
 	zconf.fsconf.success_index =
-			fds_get_index_by_name(fds, (char*) "success");	
+			fds_get_index_by_name(fds, (char*) "success");
 	if (zconf.fsconf.success_index < 0) {
 		log_fatal("fieldset", "probe module does not supply "
 				      "required success field.");
@@ -917,18 +907,15 @@ int main(int argc, char *argv[])
 		zconf.raw_output_fields = args.output_fields_arg;
 	} else if (!zconf.raw_output_fields) {
 		zconf.raw_output_fields = (char*) "saddr";
-	}	
+	}
 	if (!strcmp(zconf.raw_output_fields, "*")) {
 		zconf.output_fields_len = zconf.fsconf.defs.len;
-		zconf.output_fields = calloc(zconf.fsconf.defs.len, sizeof(char*));
-		assert(zconf.output_fields);
+		zconf.output_fields = xcalloc(zconf.fsconf.defs.len, sizeof(char*));
 		for (int i=0; i < zconf.fsconf.defs.len; i++) {
 			zconf.output_fields[i] = (char*) zconf.fsconf.defs.fielddefs[i].name;
 		}
 		fs_generate_full_fieldset_translation(&zconf.fsconf.translation,
 				&zconf.fsconf.defs);
-
-		
 	} else {
 		split_string(zconf.raw_output_fields, &(zconf.output_fields_len),
 				&(zconf.output_fields));
@@ -959,8 +946,8 @@ int main(int argc, char *argv[])
 	SET_BOOL(zconf.dryrun, dryrun);
 	SET_BOOL(zconf.quiet, quiet);
 	SET_BOOL(zconf.summary, summary);
+	SET_BOOL(zconf.ignore_invalid_hosts, ignore_invalid_hosts);
 	zconf.cooldown_secs = args.cooldown_time_arg;
-	zconf.senders = args.sender_threads_arg;
 	SET_IF_GIVEN(zconf.output_filename, output_file);
 	SET_IF_GIVEN(zconf.blacklist_filename, blacklist_file);
 	SET_IF_GIVEN(zconf.probe_args, probe_args);
@@ -973,7 +960,7 @@ int main(int argc, char *argv[])
 
 	if (args.metadata_file_arg) {
 #ifdef JSON
-		zconf.metadata_filename = args.metadata_file_arg;				
+		zconf.metadata_filename = args.metadata_file_arg;
 		if (!strcmp(zconf.metadata_filename, "-")) {
 			zconf.metadata_file = stdout;
 		} else {
@@ -990,7 +977,6 @@ int main(int argc, char *argv[])
 #endif
 	}
 
-
 	// find if zmap wants any specific cidrs scanned instead
 	// of the entire Internet
 	zconf.destination_cidrs = args.inputs;
@@ -1004,7 +990,7 @@ int main(int argc, char *argv[])
 				"editing the default ZMap configuration at /etc/zmap/zmap.conf.");
 	}
 	SET_IF_GIVEN(zconf.whitelist_filename, whitelist_file);
-	
+
 	if (zconf.probe_module->port_args) {
 		if (args.source_port_given) {
 			char *dash = strchr(args.source_port_arg, '-');
@@ -1046,7 +1032,7 @@ int main(int argc, char *argv[])
 	}
 	if (args.gateway_mac_given) {
 		if (!parse_mac(zconf.gw_mac, args.gateway_mac_arg)) {
-			fprintf(stderr, "%s: invalid MAC address `%s'\n", 
+			fprintf(stderr, "%s: invalid MAC address `%s'\n",
 				CMDLINE_PARSER_PACKAGE, args.gateway_mac_arg);
 			exit(EXIT_FAILURE);
 		}
@@ -1076,7 +1062,7 @@ int main(int argc, char *argv[])
 	SET_IF_GIVEN(zconf.total_shards, shards);
 	if (zconf.shard_num >= zconf.total_shards) {
 		log_fatal("zmap", "With %hhu total shards, shard number (%hhu)"
-			  " must be in range [0, %hhu)", zconf.total_shards, 
+			  " must be in range [0, %hhu)", zconf.total_shards,
 			  zconf.shard_num, zconf.total_shards);
 	}
 
@@ -1133,6 +1119,41 @@ int main(int argc, char *argv[])
 		}
 	}
 
+	// blacklist
+	if (blacklist_init(zconf.whitelist_filename, zconf.blacklist_filename,
+			   zconf.destination_cidrs, zconf.destination_cidrs_len,
+			   NULL, 0)) {
+		log_fatal("zmap", "unable to initialize blacklist / whitelist");
+	}
+
+	// compute number of targets
+	uint64_t allowed = blacklist_count_allowed();
+	assert(allowed <= (1LL << 32));
+	if (allowed == (1LL << 32)) {
+		zsend.targets = 0xFFFFFFFF;
+	} else {
+		zsend.targets = allowed;
+	}
+	if (zsend.targets > zconf.max_targets) {
+		zsend.targets = zconf.max_targets;
+	}
+
+	// Set the correct number of threads, default to num_cores - 1
+	if (args.sender_threads_given) {
+		zconf.senders = args.sender_threads_arg;
+	} else {
+		int num_cores = sysconf(_SC_NPROCESSORS_ONLN);
+		zconf.senders = max(num_cores - 1, 1);
+		if (!zconf.quiet) {
+			// If monitoring, save a core for the monitor thread
+			zconf.senders = max(zconf.senders - 1, 1);
+		}
+	}
+
+	if (zconf.senders > zsend.targets) {
+		zconf.senders = max(zsend.targets, 1);
+	}
+
 	start_zmap();
 
 	fclose(log_location);
